import unittest, doctest

def test_suite():
    globs = {}
    optionflags = doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS
    suite = unittest.TestSuite()
    suite.addTest(doctest.DocFileSuite(
        'jqueryui.txt', globs=globs, optionflags=optionflags))
    return suite



import py
import os
import sys
import urllib2
import urlparse
import tempfile
from hurry.resource import generate_code, ResourceInclusion, Library

from hurry.jquery import jquery

BASEURL = 'http://ajax.googleapis.com/ajax/libs/jqueryui/'
VERSION = '1.8.2'
MINIFIED = "jquery-ui.min.js"
FULL = "jquery-ui.js"
THEME_URL = 'http://jquery-ui.googlecode.com/files/jquery-ui-themes-%s.zip' % VERSION

def prepare_jqueryui(package_dir):
    jquery_dest_path = package_dir.join('jqueryui-build')

    # remove previous jquery library build
    print 'recursively removing "%s"' % jquery_dest_path
    if jquery_dest_path.check():
        jquery_dest_path.remove()
    print 'create new "%s"' % jquery_dest_path
    jquery_dest_path.ensure(dir=True)
    
    for filename in [MINIFIED, FULL]:
        url = urlparse.urljoin(BASEURL + VERSION + '/', filename)
        print 'downloading "%s"' % url
        f = urllib2.urlopen(url)
        file_data = f.read()
        f.close()
        dest_file = jquery_dest_path.join(filename)
        print 'writing data to "%s"' % dest_file
        dest_file.write(file_data)
    
    # now set up themes
    print "remove previous themes"
    themes_dest_path = package_dir.join('jqueryui-themes')
    if themes_dest_path.check():
        themes_dest_path.remove()
 
    print "downloading themes"
    f = urllib2.urlopen(THEME_URL)
    file_data = f.read()
    f.close()

    temp_dir = py.path.local.mkdtemp()
    
    zip_file = temp_dir.join('zipfile.zip')
    zip_file.write(file_data)
    
    print "unzipping themes"
    unzip_dir = temp_dir.join('unzipped')
    os.system('unzip -qq "%s" -d "%s"' % (zip_file, unzip_dir.strpath))

  
    print "copying themes"
    try:
        for dir in unzip_dir.listdir():
            if dir.check(dir=True):
                themes_dir = dir.join('themes')
                break
        themes_dir.copy(themes_dest_path)
    finally:
        temp_dir.remove()

    print "generating theme information"
    py_path = package_dir.join('_themes.py')
    print 'Generating inclusion module "%s"' % py_path

    library = Library('jqueryui_themes', 'jqueryui-themes')
    inclusion_map = {}
    for theme in themes_dest_path.listdir():
        if not theme.check(dir=True):
            continue
        if theme.basename.startswith('.'):
            continue
        theme_name = str(theme.basename)
        python_theme_name = theme_name.replace('-', '_')
        inclusion = inclusion_map[python_theme_name] = ResourceInclusion(
            library, '%s/jquery-ui.css' % theme_name)

    code = generate_code(**inclusion_map)
    module = py_path.open('w')
    module.write(code)
    module.close()

def main():
    prepare_jqueryui(py.path.local(os.path.dirname(__file__)))

def working_entrypoint(data):
    if data['name'] != 'hurry.jqueryui':
        return
    prepare_jqueryui(py.path.local(os.path.dirname(__file__)))

def tag_entrypoint(data):
    if data['name'] != 'hurry.jqueryui':
        return
    prepare_jqueryui(py.path.local(data['tagdir'] + '/src/hurry/jqueryui'))



from hurry.resource import Library, ResourceInclusion

jqueryui_themes = Library('jqueryui_themes', 'jqueryui-themes')

cupertino = ResourceInclusion(jqueryui_themes, 'cupertino/jquery-ui.css')
flick = ResourceInclusion(jqueryui_themes, 'flick/jquery-ui.css')
pepper_grinder = ResourceInclusion(jqueryui_themes, 'pepper-grinder/jquery-ui.css')
mint_choc = ResourceInclusion(jqueryui_themes, 'mint-choc/jquery-ui.css')
vader = ResourceInclusion(jqueryui_themes, 'vader/jquery-ui.css')
swanky_purse = ResourceInclusion(jqueryui_themes, 'swanky-purse/jquery-ui.css')
ui_darkness = ResourceInclusion(jqueryui_themes, 'ui-darkness/jquery-ui.css')
start = ResourceInclusion(jqueryui_themes, 'start/jquery-ui.css')
dot_luv = ResourceInclusion(jqueryui_themes, 'dot-luv/jquery-ui.css')
south_street = ResourceInclusion(jqueryui_themes, 'south-street/jquery-ui.css')
excite_bike = ResourceInclusion(jqueryui_themes, 'excite-bike/jquery-ui.css')
dark_hive = ResourceInclusion(jqueryui_themes, 'dark-hive/jquery-ui.css')
humanity = ResourceInclusion(jqueryui_themes, 'humanity/jquery-ui.css')
trontastic = ResourceInclusion(jqueryui_themes, 'trontastic/jquery-ui.css')
redmond = ResourceInclusion(jqueryui_themes, 'redmond/jquery-ui.css')
le_frog = ResourceInclusion(jqueryui_themes, 'le-frog/jquery-ui.css')
sunny = ResourceInclusion(jqueryui_themes, 'sunny/jquery-ui.css')
blitzer = ResourceInclusion(jqueryui_themes, 'blitzer/jquery-ui.css')
base = ResourceInclusion(jqueryui_themes, 'base/jquery-ui.css')
hot_sneaks = ResourceInclusion(jqueryui_themes, 'hot-sneaks/jquery-ui.css')
black_tie = ResourceInclusion(jqueryui_themes, 'black-tie/jquery-ui.css')
overcast = ResourceInclusion(jqueryui_themes, 'overcast/jquery-ui.css')
ui_lightness = ResourceInclusion(jqueryui_themes, 'ui-lightness/jquery-ui.css')
eggplant = ResourceInclusion(jqueryui_themes, 'eggplant/jquery-ui.css')
smoothness = ResourceInclusion(jqueryui_themes, 'smoothness/jquery-ui.css')


from hurry.resource import Library, ResourceInclusion
from hurry.jquery import jquery
try:
    from hurry.jqueryui._themes import *
except ImportError:
    pass

jqueryui_lib = Library('jqueryui', 'jqueryui-build')

jqueryui = ResourceInclusion(jqueryui_lib, 'jquery-ui.js', depends=[jquery],
                             minified='jquery-ui.min.js')

